@@ -2,8 +2,8 @@
 
 ;; Author: Chmouel Boudjnah
 ;; Maintainer: Chmouel Boudjnah
-;; Package-Version: 20250923.702
-;; Package-Revision: edbc8dcd14fa
+;; Package-Version: 20260127.1547
+;; Package-Revision: b12e08d925ba
 ;; Package-Requires: ((emacs "29.1") (gotest "0.16.0"))
 ;; Homepage: https://github.com/chmouel/gotest-ts.el
 ;; Keywords: languages, go, tests, tree-sitter
@@ -190,7 +190,7 @@ This command intelligently determines what test to run based on the cursor posit
   (condition-case err
       (let ((test-pattern (gotest-ts--build-test-pattern)))
         (message "Running test: %s" test-pattern)
-        (go-test--go-test (concat "-run " test-pattern " .")))
+        (go-test--go-test (concat "-run '" test-pattern "' .")))
 
     (error
      (message "Error running test: %s" (error-message-string err)))))
@@ -208,7 +208,7 @@ This command intelligently determines what test to run based on the cursor posit
 
     (let ((test-pattern (format "^%s$" func-name)))
       (message "Running test function: %s" test-pattern)
-      (go-test--go-test (concat "-run " test-pattern " .")))))
+      (go-test--go-test (concat "-run '" test-pattern "' .")))))
 
 ;;;###autoload
 (defun gotest-ts-show-test-info ()
